Skip to contents

Helper functions to get processed experiment, plots, tables or data from a glysmith result object.

Usage

cast_exp(x)

cast_plot(x, name = NULL)

cast_table(x, name = NULL)

cast_data(x, name = NULL)

Arguments

x

A glysmith result object.

name

The name of the plot or table to get. If not specified, return available names.

Value

Examples

if (FALSE) { # \dontrun{
library(glyexp)
exp <- real_experiment2
result <- forge_analysis(exp)
cast_exp(result)
cast_table(result)
cast_table(result, "summary")
} # }