Step: Adjust Protein Abundance
step_adjust_protein.RdAdjust glycoform quantification values by correcting for protein abundance
utilizing glyclean::adjust_protein().
Usually this step should be run after step_preprocess().
This step requires exp (experiment data).
Arguments
- pro_expr_path
Path to the protein expression matrix file. If
NULL, this step will be skipped. Can be:A CSV/TSV file with the first column as protein accessions and remaining columns as sample names.
An RDS file with a matrix or data.frame with row names as protein accessions and columns as sample names.
- method
The method to use for protein adjustment. Either "ratio" or "reg". Default is "ratio".
Details
Data required:
exp: The experiment to adjust
Data generated:
unadj_exp: The original experiment (previousexp, saved for reference)
This step is special in that it silently overwrites the exp data with the adjusted experiment.
This ensures that no matter if adjustment is performed or not,
the "active" experiment is always under the key exp.
The previous exp is saved as unadj_exp for reference.
Examples
fake_pro_expr_mat <- matrix(rnorm(100), nrow = 10, ncol = 10)
rownames(fake_pro_expr_mat) <- paste0("P", seq_len(10))
colnames(fake_pro_expr_mat) <- paste0("S", seq_len(10))
fake_pro_expr_path <- tempfile(fileext = ".rds")
saveRDS(fake_pro_expr_mat, fake_pro_expr_path)
step_adjust_protein(fake_pro_expr_path)
#> <step "step_adjust_protein(pro_expr_path = fake_pro_expr_path)"> Protein
#> adjustment