Step: Infer Glycan Structures
step_infer_structure.RdInfer glycan structures from the glycan_composition column in var_info.
This step uses glyanno::comp_to_struc() with a structure database from
glydb::glydb_structures() and keeps only variables with an inferred
structure.
This step requires exp (experiment data).
Arguments
- species
Species name used to restrict the glycan structure database. Default is
NULL, which does not restrict by species.- structure_level
Structure level passed to
glydb::glydb_structures(). One of"intact","topological", or"basic". Default is"topological".
Details
Data required:
exp: The experiment whose glycan structures should be inferred
Data generated:
uninferred_exp: The original experiment before structure inference
Tables generated:
inferred_structures: A table containing the inferred structure for each original variable and whether inference succeeded.