Step: Significant Variables Boxplot
step_sig_boxplot.RdCreate boxplots for the most significant variables from DEA analysis using
glyvis::plot_boxplot(). The function selects the top n_top variables with
the lowest adjusted p-values from the DEA results and plots their expression
values grouped by sample groups.
This step depends on the on parameter (default: sig_exp).
When
on = "sig_exp", requiressig_expfrom one ofstep_dea_limma(),step_dea_ttest(),step_dea_wilcox(),step_dea_anova(), orstep_dea_kruskal().When
on = "sig_trait_exp", requiressig_trait_expfrom DEA on traits.When
on = "sig_dynamic_motif_exp", requiressig_dynamic_motif_expfrom DEA on motifs.When
on = "sig_branch_motif_exp", requiressig_branch_motif_expfrom DEA on motifs.
The number of variables is limited to a maximum of 25, as enforced by
glyvis::plot_boxplot().
Usage
step_sig_boxplot(
on = "sig_exp",
n_top = 25,
panel_width = 1.5,
panel_height = 1.2,
min_width = 5,
min_height = 3,
max_width = 14,
max_height = 12,
...
)Arguments
- on
Name of the experiment data in
ctx$datato plot. One of "sig_exp", "sig_trait_exp", "sig_dynamic_motif_exp", "sig_branch_motif_exp". Default is "sig_exp".- n_top
Number of top significant variables to plot. Must be between 1 and 25 (inclusive). Default is 25.
- panel_width
Width of each panel in inches. Default is 1.5.
- panel_height
Height of each panel in inches. Default is 1.2.
- min_width
Minimum plot width in inches. Default is 5.
- min_height
Minimum plot height in inches. Default is 3.
- max_width
Maximum plot width in inches. Default is 14.
- max_height
Maximum plot height in inches. Default is 12.
- ...
Additional arguments passed to
glyvis::plot_boxplot().
Details
Data required:
Depends on
onparameter:sig_exp(default): Significant experiment from DEAsig_trait_exp: Significant trait experiment from DTAsig_dynamic_motif_exp: Significant dynamic motif experiment from DMAsig_branch_motif_exp: Significant branch motif experiment from DMA
Plots generated:
sig_boxplot: A boxplot of significant variables (ifon = "sig_exp")sig_trait_boxplot: A boxplot of significant traits (ifon = "sig_trait_exp")sig_dynamic_motif_boxplot: A boxplot of significant dynamic motifs (ifon = "sig_dynamic_motif_exp")sig_branch_motif_boxplot: A boxplot of significant branch motifs (ifon = "sig_branch_motif_exp")
Examples
step_sig_boxplot()
#> <step "step_sig_boxplot()"> Significant variables boxplot of significant
#> variables
step_sig_boxplot(n_top = 12)
#> <step "step_sig_boxplot(n_top = 12)"> Significant variables boxplot of
#> significant variables
step_sig_boxplot(on = "sig_trait_exp")
#> <step "step_sig_boxplot(on = \"sig_trait_exp\")"> Significant variables boxplot
#> of significant traits