Skip to contents

Perform NCG enrichment analysis on differentially expressed variables using glyfun::enrich_ora_ncg().

This step requires dea_res (differential analysis result from DEA). Run one of step_dea_limma(), step_dea_ttest(), or step_dea_wilcox() before this step. Only execute for glycoproteomics experiments with exactly 2 groups. If used for glycomics experiments, the step will be skipped. Use all genes in OrgDb as the background.

Usage

step_sig_enrich_ncg(
  universe = "all",
  plot_type = "dotplot",
  plot_width = 7,
  plot_height = 7,
  ...
)

Arguments

universe

The universe (background) to use for enrichment analysis. One of "all" (all genes in OrgDb), "detected" (detected variables in exp).

plot_type

Plot type for enrichment results ("dotplot", "barplot", etc.).

plot_width

Width of the plot in inches. Default is 7.

plot_height

Height of the plot in inches. Default is 7.

...

Additional arguments passed to glyfun::enrich_ora_ncg().

Value

A glysmith_step object.

Details

Data required:

  • exp: The experiment to perform NCG enrichment analysis for

  • dea_res: The result from DEA, generated by step_dea_xxx().

Tables generated:

  • ncg_enrich: A table containing the NCG enrichment results.

AI Prompt

This section is for AI in inquire_blueprint() only.

  • Include this step if user asks for it.

  • Leave universe to "all" (by default) unless the user explicitly mentions that the background should be the detected variables in exp.

  • If the experiment has more than 2 groups but the user wants enrichment for a specific two-group comparison, ask which two groups to compare and include step_subset_groups(groups = c("A", "B")) before DEA and enrichment steps.

Examples

step_sig_enrich_ncg()
#> <step "step_sig_enrich_ncg()"> NCG enrichment analysis
step_sig_enrich_ncg(plot_type = "barplot")
#> <step "step_sig_enrich_ncg(plot_type = \"barplot\")"> NCG enrichment analysis